﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics.Olap;
using Infragistics.Olap.FlatData;
using Infragistics.Controls.Grids;

namespace PivotGridCustomers
{
    public class OrdersCollection : ObservableCollection<Orders>
    {
        public OrdersCollection()
        {
            ObservableCollection<Orders> orders = OrdersGenerator.GenerateOrder(500);
            foreach(Orders order in orders)
            {
                this.Add(order);
            }
        }

    }

    public class Orders
    {
        public Orders()
        {
            this.Customer = new Customer();
            this.Order = new Order();
        }
        public Order Order { get; set; }
        public Customer Customer { get; set; }
        public string City
        {
            get { return Customer.City; }
            set { Customer.City = value; }
        }
        public double Price
        { 
            get { return Order.Price; }
            set { Order.Price = value; }
        }
        public int NumberOfUnits { get; set; }
        public double AmountOfSale
        {
            get { return Price * NumberOfUnits; }
            set { Order.Price = value / NumberOfUnits; }
        }
    }

    public class Customer
    {
        public string Name { get; set; }
        public string City { get; set; }
    }

    public class Order
    {
        public Order(){ }
        public string Product { get; set;}
        public double Price{ get; set; }
    }

    public class OrdersGenerator
    {
        private static String[] _products;
        private static String[] _customerNames;
        private static String[] _cities;
        private static readonly Random Random = new Random();
        public static ObservableCollection<Orders> GenerateOrder(int numberOfSales)
        {
            _products = "Accessories;Bikes;Clothing;Components".Split(';');
            _customerNames = "John Smith;Alfredo Fetuchini;Howard Sprouse;Russell Shorter;Nicholas Carmona;Larry Lieb;Carl Costello;Benjamin Dupree;Bryan Culver;Monica Freitag;Lydia Burson;Harold Garvin;Walter Pang;David Haley;Glenn Landeros;Harry Tyler;Stanley Brooker;Antonio Charbonneau;Brandon Mckim;Claudia Kobayashi;Benjamin Meekins;Mark Slater;Kathe Pettel;Elisa Longbottom".Split(';');
            _cities = "Sofia;London;New York;Berlin;Seattle;Mellvile;Tokyo".Split(';');
            ObservableCollection<Orders> orders = new ObservableCollection<Orders>();
            for (double i = 0; i < numberOfSales; i++)
            {
                Orders order = new Orders
                {
                    NumberOfUnits = GetRandomNumUnits(),
                    Customer = GetRandomCustomer(),
                    Order = GetRandomOrder()
                };
                orders.Add(order);
            }
            return orders;
        }
        #region Get Random Orders
        private static Customer GetRandomCustomer()
        {
            return new Customer
            {
                City = GetRandomCity(),
                Name = GetRandomCustomerName()
            };
        }
        private static int GetRandomNumUnits()
        {
            Random a = new Random(Random.Next());
            return a.Next(1, 500);
        }

        private static string GetRandomCustomerName()
        {
            Random a = new Random(Random.Next());
            return _customerNames[a.Next(_customerNames.Length)];
        }
        private static string GetRandomCity()
        {
            Random a = new Random(Random.Next());
            return _cities[a.Next(_cities.Length)];
        }
        private static Order GetRandomOrder()
        {
            return new Order
            { 
                Product = GetRandomProductName(),
                Price = GetRandomPrice()
            };
        }
        private static string GetRandomProductName()
        {
            Random a = new Random(Random.Next());
            return _products[a.Next(_products.Length)];
        }
        private static double GetRandomPrice()
        {
            Random a = new Random(Random.Next());
            return a.NextDouble() * 100;
        }
        #endregion
    }
}
